@@ -635,19 +635,29 @@ def format_cmd(manifest):
 @click.option(
     "--api",
     "-a",
-    help="The api endpoint of your scle test workcell instance.",
+    help="The api endpoint of your test dashboard, or the scle test workcell instance (if used with --no-redirect).",
     required=True,
 )
+@click.option(
+    "--no-redirect",
+    help="If set, the api endpoint given is the scle test workcell instance.",
+    is_flag=True,
+)
 @click.option(
     "--workcell-id",
     "-w",
-    help="The workcell id to use for the device set. This is not permitted along with the `deviceSet` option.",
+    help="The workcell id to use for the device set (wc4-mcx1, tst-01-mcx-01, etc.). This is not permitted along with the `device-set` or `session-id` option.",
 )
 @click.option(
     "--device-set",
     "-d",
     type=click.File("r"),
-    help="A DeviceSet json file to use for scheduling. This is not permitted along with the `workcellId` option.",
+    help="A DeviceSet json file to use for scheduling. This is not permitted along with the `workcell-id` or `session-id` options.",
+)
+@click.option(
+    "--session-id",
+    "-s",
+    help="The session id of the session that should be used for scheduling this run. This is not permitted along with the `workcell-id` or `device-set` options.",
 )
 @click.option(
     "--time-limit",
@@ -656,6 +666,23 @@ def format_cmd(manifest):
     default=30,
     help="The maximum time in seconds to spend scheduling. The scheduler will use all the time until an optimal solution is found.",
 )
+@click.option(
+    "--schedule-at",
+    default=None,
+    help="The absolute time at which the given protocol should start (at the earliest). Absolute time format YYYY-MM-DDThh:mm in the local time of the target workcell (if year, month, or day is missing, it will be auto filled with the current values).",
+)
+@click.option(
+    "--schedule-delay",
+    type=click.INT,
+    default=None,
+    help="Delay in minutes at which the given protocol should start (at the earliest).",
+)
+@click.option(
+    "--time-constraints-are-suggestion",
+    "-tc-suggestion",
+    help="If set, the time constraints will be considered only a suggestion.",
+    is_flag=True,
+)
 @click.option(
     "--partition-group-size",
     type=click.INT,
@@ -676,9 +703,14 @@ def format_cmd(manifest):
 def execute(
     autoprotocol,
     api,
+    no_redirect,
     workcell_id,
     device_set,
+    session_id,
     time_limit,
+    schedule_at,
+    schedule_delay,
+    time_constraints_are_suggestion,
     partition_group_size,
     partition_horizon,
     partitioning_swap_device_id,
@@ -687,9 +719,14 @@ def execute(
     commands.execute(
         autoprotocol,
         api,
+        no_redirect,
         workcell_id,
         device_set,
+        session_id,
         time_limit,
+        schedule_at,
+        schedule_delay,
+        time_constraints_are_suggestion,
         partition_group_size,
         partition_horizon,
         partitioning_swap_device_id,
